durtools.rational_to_duration_pair_with_specified_integer_denominator
=====================================================================

.. autofunction:: abjad.tools.durtools.rational_to_duration_pair_with_specified_integer_denominator
